@@ -24,6 +24,7 @@ import re
 import time
 import xml.etree.ElementTree as ET
 
+import setzer.helpers.path as path_helpers
 import setzer.helpers.timer as timer
 
 
@@ -74,7 +75,7 @@ class AutocompleteProvider(object):
         self.parse_included_files()
         GObject.timeout_add(2000, self.parse_included_files)
 
-    def get_items_for_completion_window(self, current_word, last_tabbed_command):
+    def get_items_for_completion_window(self, current_word, last_tabbed_command=None):
         items = list()
 
         items_all = self.get_items(current_word)
@@ -97,7 +98,7 @@ class AutocompleteProvider(object):
 
         return items
 
-    def get_begin_end_items(self, word, last_tabbed_command):
+    def get_begin_end_items(self, word, last_tabbed_command=None):
         try: items_all = self.static_begin_end_proposals[word.lower()]
         except KeyError: items = list()
         else:
@@ -193,7 +194,7 @@ class AutocompleteProvider(object):
         pathnames_done = set()
         if self.workspace.active_document != None:
             pathnames_done = pathnames_done | {self.workspace.active_document.get_filename()}
-            bibitems_first = bibitems_first | self.workspace.active_document.content.get_bibitems()
+            bibitems_first = bibitems_first | self.workspace.active_document.get_bibitems()
 
             included_files = self.get_included_files(self.workspace.active_document)
             for pathname in included_files:
@@ -206,7 +207,7 @@ class AutocompleteProvider(object):
                     else:
                         document_object = self.workspace.get_document_by_filename(pathname)
                         if document_object:
-                            bibitems_second = bibitems_second | document_object.content.get_bibitems()
+                            bibitems_second = bibitems_second | document_object.get_bibitems()
 
         for document in self.workspace.open_documents:
             pathnames = {document.get_filename()} | self.get_included_files(document)
@@ -220,7 +221,7 @@ class AutocompleteProvider(object):
                     else:
                         document_object = self.workspace.get_document_by_filename(pathname)
                         if document_object:
-                            bibitems_rest = bibitems_rest | document_object.content.get_bibitems()
+                            bibitems_rest = bibitems_rest | document_object.get_bibitems()
 
         bibitems = ['•'] + list(bibitems_first) + list(bibitems_second) + list(bibitems_rest)
         return bibitems
@@ -233,7 +234,7 @@ class AutocompleteProvider(object):
         pathnames_done = set()
         if self.workspace.active_document != None:
             pathnames_done = pathnames_done | {self.workspace.active_document.get_filename()}
-            labels_first = labels_first | self.workspace.active_document.content.get_labels()
+            labels_first = labels_first | self.workspace.active_document.get_labels()
 
             included_files = self.get_included_files(self.workspace.active_document)
             for pathname in included_files:
@@ -246,7 +247,7 @@ class AutocompleteProvider(object):
                     else:
                         document_object = self.workspace.get_document_by_filename(pathname)
                         if document_object:
-                            labels_second = labels_second | document_object.content.get_labels()
+                            labels_second = labels_second | document_object.get_labels()
 
         for document in self.workspace.open_documents:
             pathnames = {document.get_filename()} | self.get_included_files(document)
@@ -260,7 +261,7 @@ class AutocompleteProvider(object):
                     else:
                         document_object = self.workspace.get_document_by_filename(pathname)
                         if document_object:
-                            labels_rest = labels_rest | document_object.content.get_labels()
+                            labels_rest = labels_rest | document_object.get_labels()
 
         labels = ['•'] + list(labels_first) + list(labels_second) + list(labels_rest)
         return labels
@@ -315,8 +316,9 @@ class AutocompleteProvider(object):
         dirname = document.get_dirname()
 
         filenames = set()
-        for filename in document.content.get_included_latex_files():
-            filenames |= {os.path.normpath(os.path.join(dirname, filename))}
+        if document.get_included_latex_files():
+            for filename, offset in document.get_included_latex_files():
+                filenames |= {path_helpers.get_abspath(filename, dirname)}
 
         return filenames
 
@@ -324,8 +326,8 @@ class AutocompleteProvider(object):
         dirname = document.get_dirname()
 
         filenames = set()
-        for filename in document.content.get_bibliography_files():
-            filenames |= {os.path.normpath(os.path.join(dirname, filename))}
+        for filename in document.get_bibliography_files():
+            filenames |= {path_helpers.get_abspath(filename, dirname)}
 
         return filenames
 
