@@ -50,7 +50,8 @@ class Settings(Observable):
         self.defaults['window_state']['width'] = 1020
         self.defaults['window_state']['height'] = 550
         self.defaults['window_state']['is_maximized'] = False
-        self.defaults['window_state']['show_sidebar'] = False
+        self.defaults['window_state']['show_symbols'] = False
+        self.defaults['window_state']['show_document_structure'] = False
         self.defaults['window_state']['sidebar_paned_position'] = -1
         self.defaults['window_state']['show_help'] = False
         self.defaults['window_state']['show_preview'] = False
@@ -109,12 +110,6 @@ class Settings(Observable):
             self.set_value(section, item, value)
         return value
 
-    def get_source_buffer_options(self):
-        buffer_options = dict()
-        buffer_options['tab_width'] = self.get_value('preferences', 'tab_width')
-        buffer_options['spaces_instead_of_tabs'] = self.get_value('preferences', 'spaces_instead_of_tabs')
-        return buffer_options
-
     def set_value(self, section, item, value):
         try: section_dict = self.data[section]
         except KeyError:
