@@ -28,18 +28,15 @@ import time
 import difflib
 import math
 
-import setzer.document.content.parser.parser_dummy as parser_dummy
-import setzer.document.content.parser.parser_bibtex as parser_bibtex
-import setzer.document.content.parser.parser_latex as parser_latex
 from setzer.app.service_locator import ServiceLocator
 from setzer.helpers.observable import Observable
-import setzer.helpers.timer as timer
 
 
 class Content(Observable):
 
-    def __init__(self, language):
+    def __init__(self, language, document):
         Observable.__init__(self)
+        self.document = document
 
         self.settings = ServiceLocator.get_settings()
 
@@ -47,35 +44,12 @@ class Content(Observable):
         self.source_view = GtkSource.View.new_with_buffer(self.source_buffer)
         self.source_language_manager = ServiceLocator.get_source_language_manager()
         self.source_style_scheme_manager = ServiceLocator.get_source_style_scheme_manager()
-
         if language == 'bibtex': self.source_language = self.source_language_manager.get_language('bibtex')
         else: self.source_language = self.source_language_manager.get_language('latex')
-
         self.source_buffer.set_language(self.source_language)
         self.update_syntax_scheme()
 
-        self.symbols = dict()
-        self.symbols['bibitems'] = set()
-        self.symbols['labels'] = set()
-        self.symbols['included_latex_files'] = set()
-        self.symbols['bibliographies'] = set()
-        self.symbols['packages'] = set()
-        self.symbols['packages_detailed'] = dict()
-        self.symbols['blocks'] = list()
-
-        if language == 'bibtex': self.parser = parser_bibtex.ParserBibTeX(self)
-        elif language == 'latex': self.parser = parser_latex.ParserLaTeX(self)
-        else: self.parser = parser_dummy.ParserDummy(self)
-
-        self.color_manager = ServiceLocator.get_color_manager()
-        self.font_manager = ServiceLocator.get_font_manager()
-
-        options = self.settings.get_source_buffer_options()
-        self.tab_width = options['tab_width']
-        self.spaces_instead_of_tabs = options['spaces_instead_of_tabs']
-
-        self.mover_mark = self.source_buffer.create_mark('mover', self.source_buffer.get_start_iter(), True)
-
+        self.scroll_to = None
         self.insert_position = 0
 
         self.synctex_tag_count = 0
@@ -97,26 +71,21 @@ class Content(Observable):
         self.undo_manager = self.source_buffer.get_undo_manager()
         self.undo_manager.connect('can-undo-changed', self.on_can_undo_changed)
         self.undo_manager.connect('can-redo-changed', self.on_can_redo_changed)
-
         self.settings.connect('settings_changed', self.on_settings_changed)
 
     def on_settings_changed(self, settings, parameter):
         section, item, value = parameter
-        if (section, item) == ('preferences', 'tab_width'):
-            self.tab_width = self.settings.get_value('preferences', 'tab_width')
-        if (section, item) == ('preferences', 'spaces_instead_of_tabs'):
-            self.spaces_instead_of_tabs = self.settings.get_value('preferences', 'spaces_instead_of_tabs')
 
         if (section, item) in [('preferences', 'syntax_scheme'), ('preferences', 'syntax_scheme_dark_mode')]:
             self.update_syntax_scheme()
 
     def on_insert_text(self, buffer, location_iter, text, text_length):
-        self.parser.on_text_inserted(buffer, location_iter, text, text_length)
+        self.document.parser.on_text_inserted(buffer, location_iter, text, text_length)
         self.indentation_update = {'line_start': location_iter.get_line(), 'text_length': text_length}
         self.add_change_code('text_inserted', (buffer, location_iter, text, text_length))
 
     def on_delete_range(self, buffer, start_iter, end_iter):
-        self.parser.on_text_deleted(buffer, start_iter, end_iter)
+        self.document.parser.on_text_deleted(buffer, start_iter, end_iter)
         self.indentation_update = {'line_start': start_iter.get_line(), 'text_length': 0}
         self.add_change_code('text_deleted', (buffer, start_iter, end_iter))
 
@@ -144,12 +113,12 @@ class Content(Observable):
     def on_mark_set(self, buffer, insert, mark, user_data=None):
         if mark.get_name() == 'insert':
             self.update_placeholder_selection()
-            self.add_change_code('insert_mark_set')
+            self.add_change_code('cursor_changed')
         self.update_selection_state()
 
     def on_mark_deleted(self, buffer, mark, user_data=None):
         if mark.get_name() == 'insert':
-            self.add_change_code('insert_mark_deleted')
+            self.add_change_code('cursor_changed')
         self.update_selection_state()
 
     def initially_set_text(self, text):
@@ -181,7 +150,6 @@ class Content(Observable):
     def get_can_redo(self):
         return self.undo_manager.can_redo()
 
-    #@timer.timer
     def update_indentation_tags(self):
         if self.indentation_update != None:
             start_iter = self.source_buffer.get_iter_at_line(self.indentation_update['line_start'])
@@ -193,7 +161,7 @@ class Content(Observable):
             for count, line in enumerate(text.splitlines()):
                 for tag in start_iter.get_tags():
                     self.source_buffer.remove_tag(tag, start_iter, end_iter)
-                number_of_characters = len(line.replace('\t', ' ' * self.tab_width)) - len(line.lstrip())
+                number_of_characters = len(line.replace('\t', ' ' * self.settings.get_value('preferences', 'tab_width'))) - len(line.lstrip())
                 if number_of_characters > 0:
                     end_iter = start_iter.copy()
                     end_iter.forward_chars(1)
@@ -207,7 +175,8 @@ class Content(Observable):
             tag = self.indentation_tags[number_of_characters]
         except KeyError:
             tag = self.source_buffer.create_tag('indentation-' + str(number_of_characters))
-            tag.set_property('indent', -1 * number_of_characters * self.font_manager.get_char_width(' '))
+            font_manager = ServiceLocator.get_font_manager()
+            tag.set_property('indent', -1 * number_of_characters * font_manager.get_char_width(' '))
             self.indentation_tags[number_of_characters] = tag
         return tag
 
@@ -215,29 +184,56 @@ class Content(Observable):
         end_iter = self.source_buffer.get_end_iter()
         result = end_iter.backward_search('\\end{document}', Gtk.TextSearchFlags.VISIBLE_ONLY, None)
         if result != None:
-            self.insert_text_at_iter(result[0], '''
+            self.source_buffer.place_cursor(result[0])
+            self.insert_text_at_cursor_and_select_dot('''
 ''' + text + '''
 
-''', False)
+''')
         else:
-            self.insert_text_at_cursor(text)
+            self.insert_text_at_cursor_indent_and_select_dot(text)
 
-    def insert_text(self, line_number, offset, text, indent_lines=True):
-        insert_iter = self.source_buffer.get_iter_at_line_offset(line_number, offset)
-        self.insert_text_at_iter(insert_iter, text, indent_lines)
-
-    def insert_text_at_iter(self, insert_iter, text, indent_lines=True):
-        self.source_buffer.place_cursor(insert_iter)
-        self.insert_text_at_cursor(text, indent_lines)
-
-    def insert_text_at_cursor(self, text, indent_lines=True, select_dot=True):
+    def insert_text_at_cursor_indent_and_select_dot(self, text):
         self.source_buffer.begin_user_action()
+        text = self.replace_tabs_with_spaces_if_set(text)
+        text = self.replace_first_dot_with_selection(text)
+        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
+        text = self.indent_text_with_whitespace_at_iter(text, insert_iter)
 
-        # replace tabs with spaces, if set in preferences
-        if self.spaces_instead_of_tabs:
-            number_of_spaces = self.tab_width
+        self.insert_text_at_cursor_no_user_action(text)
+        self.select_nth_dot_before_cursor_for_n_dots_in_text(text)
+        self.source_buffer.end_user_action()
+
+    def select_nth_dot_before_cursor_for_n_dots_in_text(self, text):
+        dotindex = text.find('•')
+        if dotindex > -1:
+            start_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
+            start_iter.backward_chars(abs(dotindex - len(text)))
+            bound = start_iter.copy()
+            bound.forward_chars(1)
+            self.source_buffer.select_range(start_iter, bound)
+
+    def insert_text_at_cursor_and_select_dot(self, text):
+        self.source_buffer.begin_user_action()
+        text = self.replace_tabs_with_spaces_if_set(text)
+        text = self.replace_first_dot_with_selection(text)
+        self.insert_text_at_cursor_no_user_action(text)
+        self.select_nth_dot_before_cursor_for_n_dots_in_text(text)
+        self.source_buffer.end_user_action()
+
+    def insert_text_at_cursor(self, text):
+        self.source_buffer.begin_user_action()
+        text = self.replace_tabs_with_spaces_if_set(text)
+        text = self.replace_first_dot_with_selection(text)
+        self.insert_text_at_cursor_no_user_action(text)
+        self.source_buffer.end_user_action()
+
+    def replace_tabs_with_spaces_if_set(self, text):
+        if self.settings.get_value('preferences', 'spaces_instead_of_tabs'):
+            number_of_spaces = self.settings.get_value('preferences', 'tab_width')
             text = text.replace('\t', ' ' * number_of_spaces)
+        return text
 
+    def replace_first_dot_with_selection(self, text):
         dotcount = text.count('•')
         insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
         bounds = self.source_buffer.get_selection_bounds()
@@ -248,126 +244,44 @@ class Content(Observable):
                 selection = self.source_buffer.get_text(bounds[0], bounds[1], True)
                 if len(selection) > 0:
                     text = text.replace('•', selection, 1)
+        return text
 
-        if indent_lines:
-            line_iter = self.source_buffer.get_iter_at_line(insert_iter.get_line())
-            ws_line = self.source_buffer.get_text(line_iter, insert_iter, False)
-            lines = text.split('\n')
-            ws_number = len(ws_line) - len(ws_line.lstrip())
-            whitespace = ws_line[:ws_number]
-            final_text = ''
-            for no, line in enumerate(lines):
-                if no != 0:
-                    final_text += '\n' + whitespace
-                final_text += line
-        else:
-            final_text = text
-
+    def insert_text_at_cursor_no_user_action(self, text):
         self.source_buffer.delete_selection(False, False)
-        self.source_buffer.insert_at_cursor(final_text)
+        self.source_buffer.insert_at_cursor(text)
 
-        if select_dot:
-            dotindex = final_text.find('•')
-            if dotcount > 0:
-                selection_len = len(selection) if dotcount == 1 else 0
-                start = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-                start.backward_chars(abs(dotindex + selection_len - len(final_text)))
-                self.source_buffer.place_cursor(start)
-                end = start.copy()
-                end.forward_char()
-                self.source_buffer.select_range(start, end)
-
-        self.source_buffer.end_user_action()
-
-    def insert_template(self, template_start, template_end):
+    def replace_range_and_select_dot(self, start_iter, end_iter, text):
         self.source_buffer.begin_user_action()
-
-        bounds = self.source_buffer.get_bounds()
-        text = self.source_buffer.get_text(bounds[0], bounds[1], True)
-        line_count_before_insert = self.source_buffer.get_line_count()
-
-        # replace tabs with spaces, if set in preferences
-        if self.settings.get_value('preferences', 'spaces_instead_of_tabs'):
-            number_of_spaces = self.settings.get_value('preferences', 'tab_width')
-            template_start = template_start.replace('\t', ' ' * number_of_spaces)
-            template_end = template_end.replace('\t', ' ' * number_of_spaces)
-
-        bounds = self.source_buffer.get_bounds()
-        self.source_buffer.insert(bounds[0], template_start)
-        bounds = self.source_buffer.get_bounds()
-        self.source_buffer.insert(bounds[1], template_end)
-
-        bounds = self.source_buffer.get_bounds()
-        bounds[0].forward_chars(len(template_start))
-        self.source_buffer.place_cursor(bounds[0])
-
-        self.source_buffer.end_user_action()
-        self.source_buffer.begin_user_action()
-
-        if len(text.strip()) > 0:
-            note = _('''% NOTE: The content of your document has been commented out
-% by the wizard. Just do a CTRL+Z (undo) to put it back in
-% or remove the "%" before each line you want to keep.
-% You can remove this note as well.
-% 
-''')
-            note_len = len(note)
-            note_number_of_lines = note.count('\n')
-            offset = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert()).get_line()
-            self.source_buffer.insert(self.source_buffer.get_iter_at_line(offset), note)
-            for line_number in range(offset + note_number_of_lines, line_count_before_insert + offset + note_number_of_lines):
-                self.source_buffer.insert(self.source_buffer.get_iter_at_line(line_number), '% ')
-            insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-            insert_iter.backward_chars(note_len + 2)
-            self.source_buffer.place_cursor(insert_iter)
-
+        self.replace_range_no_user_action(start_iter, end_iter, text)
+        self.select_nth_dot_before_cursor_for_n_dots_in_text(text)
         self.source_buffer.end_user_action()
 
-    def replace_range_by_offset_and_length(self, offset, length, text, indent_lines=True, select_dot=True):
-        start_iter = self.source_buffer.get_iter_at_offset(offset)
-        end_iter = self.source_buffer.get_iter_at_offset(offset + length)
-        self.replace_range(start_iter, end_iter, text, indent_lines, select_dot)
-
-    def replace_range(self, start_iter, end_iter, text, indent_lines=True, select_dot=True):
-        self.source_buffer.begin_user_action()
-        self.replace_range_no_user_action(start_iter, end_iter, text, indent_lines, select_dot)
-        self.source_buffer.end_user_action()
-
-    def replace_range_no_user_action(self, start_iter, end_iter, text, indent_lines=True, select_dot=True):
-        if indent_lines:
-            line_iter = self.source_buffer.get_iter_at_line(start_iter.get_line())
-            ws_line = self.source_buffer.get_text(line_iter, start_iter, False)
-            lines = text.split('\n')
-            ws_number = len(ws_line) - len(ws_line.lstrip())
-            whitespace = ws_line[:ws_number]
-            final_text = ''
-            for no, line in enumerate(lines):
-                if no != 0:
-                    final_text += '\n' + whitespace
-                final_text += line
-        else:
-            final_text = text
-
+    def replace_range_no_user_action(self, start_iter, end_iter, text):
         self.source_buffer.delete(start_iter, end_iter)
-        self.source_buffer.insert(start_iter, final_text)
+        self.source_buffer.insert(start_iter, text)
 
-        if select_dot:
-            dotindex = final_text.find('•')
-            if dotindex > -1:
-                start_iter.backward_chars(abs(dotindex - len(final_text)))
-                bound = start_iter.copy()
-                bound.forward_chars(1)
-                self.source_buffer.select_range(start_iter, bound)
+    def indent_text_with_whitespace_at_iter(self, text, start_iter):
+        line_iter = self.source_buffer.get_iter_at_line(start_iter.get_line())
+        ws_line = self.source_buffer.get_text(line_iter, start_iter, False)
+        lines = text.split('\n')
+        ws_number = len(ws_line) - len(ws_line.lstrip())
+        whitespace = ws_line[:ws_number]
+        final_text = ''
+        for no, line in enumerate(lines):
+            if no != 0:
+                final_text += '\n' + whitespace
+            final_text += line
+        return final_text
 
     def insert_before_after(self, before, after):
         bounds = self.source_buffer.get_selection_bounds()
 
         if len(bounds) > 1:
             text = before + self.source_buffer.get_text(*bounds, 0) + after
-            self.replace_range(bounds[0], bounds[1], text)
+            self.replace_range_and_select_dot(bounds[0], bounds[1], text)
         else:
             text = before + '•' + after
-            self.insert_text_at_cursor(text)
+            self.insert_text_at_cursor_indent_and_select_dot(text)
 
     def comment_uncomment(self):
         self.source_buffer.begin_user_action()
@@ -401,42 +315,13 @@ class Content(Observable):
 
         self.source_buffer.end_user_action()
 
-    def add_backslash_with_space(self):
-        self.source_buffer.insert_at_cursor('\\ ')
-        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-        insert_iter.backward_char()
-        self.source_buffer.place_cursor(insert_iter)
-
-    def autoadd_latex_brackets(self, char):
-        if self.get_char_before_cursor() == '\\':
-            add_char = '\\'
-        else:
-            add_char = ''
-        if char == '[':
-            self.source_buffer.begin_user_action()
-            self.source_buffer.delete_selection(True, True)
-            self.source_buffer.insert_at_cursor('[' + add_char + ']')
-            self.source_buffer.end_user_action()
-        if char == '{':
-            self.source_buffer.begin_user_action()
-            self.source_buffer.delete_selection(True, True)
-            self.source_buffer.insert_at_cursor('{' + add_char + '}')
-            self.source_buffer.end_user_action()
-        if char == '(':
-            self.source_buffer.begin_user_action()
-            self.source_buffer.delete_selection(True, True)
-            self.source_buffer.insert_at_cursor('(' + add_char + ')')
-            self.source_buffer.end_user_action()
-        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-        insert_iter.backward_char()
-        if add_char == '\\':
-            insert_iter.backward_char()
-        self.source_buffer.place_cursor(insert_iter)
-
     def get_char_at_cursor(self):
+        return self.get_chars_at_cursor(1)
+
+    def get_chars_at_cursor(self, number_of_chars):
         start_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
         end_iter = start_iter.copy()
-        end_iter.forward_char()
+        end_iter.forward_chars(number_of_chars)
         return self.source_buffer.get_text(start_iter, end_iter, False)
 
     def get_char_before_cursor(self):
@@ -445,89 +330,14 @@ class Content(Observable):
         end_iter.backward_char()
         return self.source_buffer.get_text(start_iter, end_iter, False)
 
-    def get_latex_command_at_cursor(self):
-        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-        limit_iter = insert_iter.copy()
-        limit_iter.backward_chars(50)
-        word_start_iter = insert_iter.copy()
-        result = word_start_iter.backward_search('\\', Gtk.TextSearchFlags.TEXT_ONLY, limit_iter)
-        if result != None:
-            word_start_iter = result[0]
-        word = word_start_iter.get_slice(insert_iter)
-        return word
-
-    def get_latex_command_at_cursor_offset(self):
-        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-        limit_iter = insert_iter.copy()
-        limit_iter.backward_chars(50)
-        word_start_iter = insert_iter.copy()
-        result = word_start_iter.backward_search('\\', Gtk.TextSearchFlags.TEXT_ONLY, limit_iter)
-        if result != None:
-            word_start_iter = result[0]
-            return word_start_iter.get_offset()
-        return None
-
-    def replace_latex_command_at_cursor(self, text, dotlabels, is_full_command=False):
-        insert_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
-        current_word = self.get_latex_command_at_cursor()
-        start_iter = insert_iter.copy()
-        start_iter.backward_chars(len(current_word))
-
-        if is_full_command and text.startswith('\\begin'):
-            end_command = text.replace('\\begin', '\\end')
-            end_command_bracket_position = end_command.find('}')
-            if end_command_bracket_position:
-                end_command = end_command[:end_command_bracket_position + 1]
-            text += '\n\t•\n' + end_command
-            if self.spaces_instead_of_tabs:
-                number_of_spaces = self.tab_width
-                text = text.replace('\t', ' ' * number_of_spaces)
-            dotlabels += 'content###'
-            if end_command.find('•') >= 0:
-                dotlabels += 'environment###'
-
-            line_iter = self.source_buffer.get_iter_at_line(start_iter.get_line())
-            ws_line = self.source_buffer.get_text(line_iter, start_iter, False)
-            lines = text.split('\n')
-            ws_number = len(ws_line) - len(ws_line.lstrip())
-            whitespace = ws_line[:ws_number]
-            text = ''
-            for no, line in enumerate(lines):
-                if no != 0:
-                    text += '\n' + whitespace
-                text += line
-
-        parts = text.split('•')
-        if len(parts) == 1:
-            orig_text = self.source_buffer.get_text(start_iter, insert_iter, False)
-            if parts[0].startswith(orig_text):
-                self.source_buffer.insert_at_cursor(parts[0][len(orig_text):])
-            else:
-                self.replace_range(start_iter, insert_iter, parts[0], indent_lines=True, select_dot=True)
-        else:
-            self.source_buffer.begin_user_action()
-
-            self.source_buffer.delete(start_iter, insert_iter)
-            insert_offset = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert()).get_offset()
-            count = len(parts)
-            select_dot_offset = -1
-            for part in parts:
-                insert_iter = self.source_buffer.get_iter_at_offset(insert_offset)
-                insert_offset += len(part)
-                self.source_buffer.insert(insert_iter, part)
-                if count > 1:
-                    insert_iter = self.source_buffer.get_iter_at_offset(insert_offset)
-                    self.source_buffer.insert_with_tags(insert_iter, '•', self.placeholder_tag)
-                    if select_dot_offset == -1:
-                        select_dot_offset = insert_offset
-                    insert_offset += 1
-                count -= 1
-            select_dot_iter = self.source_buffer.get_iter_at_offset(select_dot_offset)
-            bound = select_dot_iter.copy()
-            bound.forward_chars(1)
-            self.source_buffer.select_range(select_dot_iter, bound)
-
-            self.source_buffer.end_user_action()
+    def overwrite_chars_at_cursor(self, text):
+        start_iter = self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert())
+        end_iter = start_iter.copy()
+        end_iter.forward_chars(len(text))
+        self.source_buffer.begin_user_action()
+        self.source_buffer.delete(start_iter, end_iter)
+        self.source_buffer.insert_at_cursor(text)
+        self.source_buffer.end_user_action()
 
     def get_line_at_cursor(self):
         return self.get_line(self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert()).get_line())
@@ -620,7 +430,8 @@ class Content(Observable):
     def add_synctex_tag(self, start_iter, end_iter):
         self.source_buffer.place_cursor(start_iter)
         self.synctex_tag_count += 1
-        self.source_buffer.create_tag('synctex_highlight-' + str(self.synctex_tag_count), background_rgba=self.color_manager.get_rgba(0.976, 0.941, 0.420, 0.6), background_full_height=True)
+        color_manager = ServiceLocator.get_color_manager()
+        self.source_buffer.create_tag('synctex_highlight-' + str(self.synctex_tag_count), background_rgba=color_manager.get_rgba(0.976, 0.941, 0.420, 0.6), background_full_height=True)
         tag = self.source_buffer.get_tag_table().lookup('synctex_highlight-' + str(self.synctex_tag_count))
         self.source_buffer.apply_tag(tag, start_iter, end_iter)
         if not self.synctex_highlight_tags:
@@ -665,7 +476,8 @@ class Content(Observable):
             if time_factor > 1.5:
                 if time_factor <= 1.75:
                     opacity_factor = int(self.ease(1 - (time_factor - 1.5) * 4) * 20)
-                    item['tag'].set_property('background-rgba', self.color_manager.get_rgba(0.976, 0.941, 0.420, opacity_factor * 0.03))
+                    color_manager = ServiceLocator.get_color_manager()
+                    item['tag'].set_property('background-rgba', color_manager.get_rgba(0.976, 0.941, 0.420, opacity_factor * 0.03))
                 else:
                     start = self.source_buffer.get_start_iter()
                     end = self.source_buffer.get_end_iter()
@@ -689,6 +501,27 @@ class Content(Observable):
     def get_cursor_line_number(self):
         return self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert()).get_line()
 
+    def get_line_number_at_offset(self, offset):
+        return self.source_buffer.get_iter_at_offset(offset).get_line()
+
+    def get_screen_offsets_by_iter(self, text_iter):
+        font_manager = ServiceLocator.get_font_manager()
+        line_height = font_manager.get_line_height()
+        iter_location = self.source_view.get_iter_location(text_iter)
+        gutter = self.source_view.get_window(Gtk.TextWindowType.LEFT)
+
+        if gutter != None:
+            gutter_width = gutter.get_width()
+        else:
+            gutter_width = 0
+
+        x_offset = - self.document.view.scrolled_window.get_hadjustment().get_value()
+        y_offset = - self.document.view.scrolled_window.get_vadjustment().get_value()
+        x_position = x_offset + iter_location.x - 2 + gutter_width
+        y_position = y_offset + iter_location.y + line_height
+
+        return x_position, y_position
+
     def cursor_ends_word(self):
         return self.source_buffer.get_iter_at_mark(self.source_buffer.get_insert()).ends_word()
 
@@ -729,28 +562,51 @@ class Content(Observable):
         iter_position = self.source_view.get_iter_location(text_iter).y
         end_yrange = self.source_view.get_line_yrange(self.source_buffer.get_end_iter())
         buffer_height = end_yrange.y + end_yrange.height
-        line_height = self.font_manager.get_line_height()
+        font_manager = ServiceLocator.get_font_manager()
+        line_height = font_manager.get_line_height()
         window_offset = self.source_view.get_visible_rect().y
         window_height = self.source_view.get_visible_rect().height
         gap = min(math.floor(max((visible_lines - 2), 0) / 2), 5)
         if iter_position < window_offset + gap * line_height:
-            scroll_iter = self.source_view.get_iter_at_location(0, max(iter_position - gap * line_height, 0)).iter
-            self.source_buffer.move_mark(self.mover_mark, scroll_iter)
-            self.source_view.scroll_to_mark(self.mover_mark, 0, False, 0, 0)
+            self.scroll_view(max(iter_position - gap * line_height, 0))
             return
         gap = min(math.floor(max((visible_lines - 2), 0) / 2), 8)
         if iter_position > (window_offset + window_height - (gap + 1) * line_height):
-            scroll_iter = self.source_view.get_iter_at_location(0, min(iter_position + gap * line_height, buffer_height)).iter
-            self.source_buffer.move_mark(self.mover_mark, scroll_iter)
-            self.source_view.scroll_to_mark(self.mover_mark, 0, False, 0, 0)
+            self.scroll_view(min(iter_position + gap * line_height - window_height, buffer_height))
+
+    def scroll_view(self, position, duration=0.2):
+        view = self.document.view.scrolled_window
+        adjustment = view.get_vadjustment()
+        self.scroll_to = {'position_start': adjustment.get_value(), 'position_end': position, 'time_start': time.time(), 'duration': duration}
+        view.set_kinetic_scrolling(False)
+        GObject.timeout_add(15, self.do_scroll)
+
+    def do_scroll(self):
+        view = self.document.view.scrolled_window
+        if self.scroll_to != None:
+            adjustment = view.get_vadjustment()
+            time_elapsed = time.time() - self.scroll_to['time_start']
+            if self.scroll_to['duration'] == 0:
+                time_elapsed_percent = 1
+            else:
+                time_elapsed_percent = time_elapsed / self.scroll_to['duration']
+            if time_elapsed_percent >= 1:
+                adjustment.set_value(self.scroll_to['position_end'])
+                self.scroll_to = None
+                view.set_kinetic_scrolling(True)
+                return False
+            else:
+                adjustment.set_value(self.scroll_to['position_start'] * (1 - self.ease(time_elapsed_percent)) + self.scroll_to['position_end'] * self.ease(time_elapsed_percent))
+                return True
+        return False
+
+    def ease(self, time): return (time - 1)**3 + 1
 
     def get_number_of_visible_lines(self):
-        line_height = self.font_manager.get_line_height()
+        font_manager = ServiceLocator.get_font_manager()
+        line_height = font_manager.get_line_height()
         return math.floor(self.source_view.get_visible_rect().height / line_height)
 
-    def get_bibitems(self):
-        return self.symbols['bibitems']
-
     def add_packages(self, packages):
         first_package = True
         text = ''
@@ -759,7 +615,7 @@ class Content(Observable):
             text += '\\usepackage{' + packagename + '}'
             first_package = False
         
-        package_data = self.get_package_details()
+        package_data = self.document.get_package_details()
         if package_data:
             max_end = 0
             for package in package_data.items():
@@ -768,18 +624,20 @@ class Content(Observable):
             insert_iter = self.source_buffer.get_iter_at_offset(max_end)
             if not insert_iter.ends_line():
                 insert_iter.forward_to_line_end()
-            self.insert_text_at_iter(insert_iter, '\n' + text)
+            self.source_buffer.place_cursor(insert_iter)
+            self.insert_text_at_cursor_indent_and_select_dot('\n' + text)
         else:
             end_iter = self.source_buffer.get_end_iter()
             result = end_iter.backward_search('\\documentclass', Gtk.TextSearchFlags.VISIBLE_ONLY, None)
             if result != None:
                 result[0].forward_to_line_end()
-                self.insert_text_at_iter(result[0], '\n' + text)
+                self.source_buffer.place_cursor(result[0])
+                self.insert_text_at_cursor_indent_and_select_dot('\n' + text)
             else:
-                self.insert_text_at_cursor(text)
+                self.insert_text_at_cursor_indent_and_select_dot(text)
 
     def remove_packages(self, packages):
-        packages_dict = self.get_package_details()
+        packages_dict = self.document.get_package_details()
         for package in packages:
             try:
                 match_obj = packages_dict[package]
@@ -792,25 +650,4 @@ class Content(Observable):
                     start_iter.backward_char()
                 self.source_buffer.delete(start_iter, end_iter)
 
-    def get_packages(self):
-        return self.symbols['packages']
-
-    def get_package_details(self):
-        return self.symbols['packages_detailed']
-
-    def get_blocks(self):
-        return self.symbols['blocks']
-
-    def set_blocks(self, blocks):
-        self.symbols['blocks'] = blocks
-
-    def get_included_latex_files(self):
-        return self.symbols['included_latex_files']
-
-    def get_bibliography_files(self):
-        return self.symbols['bibliographies']
-
-    def get_labels(self):
-        return self.symbols['labels']
-
 
