@@ -65,10 +65,10 @@ class DocumentSwitcherPresenter(object):
     def on_docswitcher_mode_change(self, document_switcher, mode):
         self.activate_mode(mode)
 
-    def on_filename_change(self, document, filename):
+    def on_filename_change(self, document, filename=None):
         self.show_document_name(document)
 
-    def on_displayname_change(self, document, displayname):
+    def on_displayname_change(self, document):
         self.show_document_name(document)
 
     def on_modified_changed(self, content):
@@ -123,7 +123,7 @@ class DocumentSwitcherPresenter(object):
         self.button.set_visible_child_name('welcome')
 
     def show_document_name(self, document):
-        mod_text = '*' if document.get_modified() else ''
+        mod_text = '*' if document.content.get_modified() else ''
         self.button.document_name_label.set_text(document.get_basename() + mod_text)
         dirname = document.get_dirname()
         if dirname != '':
