@@ -20,12 +20,11 @@ gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 
 
-class Sidebar(Gtk.Notebook):
+class Sidebar(Gtk.Stack):
 
     def __init__(self):
-        Gtk.Notebook.__init__(self)
+        Gtk.Stack.__init__(self)
 
         self.get_style_context().add_class('sidebar')
-        self.set_show_tabs(False)
 
 
